﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using static Spcidevdll;

// This routine controls the analog input channels of the data acquisition card for single-channel, single-point acquisition, obtaining one data point each time.
// This routine is applicable to the following models:
// PCI - 225x
// PCI - 3xxx
// PCI - 5xxx

namespace ai_one_point
{
    class Program
    {
        static int Main(string[] args)
        {
            int rst;
            int DevIndex = 0;
            float AiValue = 0;

            // Open the device
            rst = OpenDevice(DevIndex);
            if (rst < 0) { return rst; }

            // Set the Ai acquisition mode to single-point acquisition
            rst = SetAiSampleMode(DevIndex, 0);
            if (rst < 0) { return rst; }

            // Set the Ai range to 1.
            // For the PCI - 225x/5000 series, the last parameter 0 in the function is meaningless.
            // For the PCI - 3000 series, this specifies to set the range of channel 0.
            rst = SetAiRange(DevIndex, 1, 0);
            if (rst < 0) { return rst; }

            // Set the Ai connection type to RSE
            rst = SetAiConnectType(DevIndex, 0);
            if (rst < 0) { return rst; }

            // Read the result of single-point acquisition of the analog input.
            // Here, channel 0 is read.
            rst = GetAiOnePoint(DevIndex, 0, ref AiValue);
            if (rst < 0) { return rst; }

            Console.WriteLine("AiValue = {0}", AiValue);

            // Close the device
            rst = CloseDevice(DevIndex);
            if (rst < 0) { return rst; }

            return 0;
        }
    }
}