﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using static Spcidevdll;

// This routine controls the single-shot acquisition of the analog input channels of the data acquisition card. The number of points to be collected per channel each time needs to be set.
// This routine is applicable to the following models:
// PCI - 225x
// PCI - 3xxx
// PCI - 5xxx

namespace ai_oneshot
{
    class Program
    {
        static int Main(string[] args)
        {
            int rst;
            uint i;
            int DevIndex = 0;
            float[] AiValue = new float[8000];
            uint AiFifoUsdw = 0;

            // Open the device
            rst = OpenDevice(DevIndex);
            if (rst < 0) { return rst; }

            // Set the Ai connection type to RSE
            rst = SetAiConnectType(DevIndex, 0);
            if (rst < 0) { return rst; }

            // Set the selection of Ai acquisition channels
            // Here, channels ai 0 to ai 7 are selected, a total of 8 channels
            rst = SetAiChannelSellect(DevIndex, 0x00ff);

            // Set the Ai acquisition mode to OneShot
            rst = SetAiSampleMode(DevIndex, 1);
            if (rst < 0) { return rst; }

            // Set the Ai sampling period to 10000ns, that is, 100kS/s
            rst = SetAiSamplePeriod(DevIndex, 10000);
            if (rst < 0) { return rst; }

            // Set the Ai range to 1.
            // For the PCI - 3000 series, channels 0 to 7 are all set to range 1 here.
            // For the PCI - 225x/5000 series, there is no need to set it 8 times in a loop, once is enough.
            for (i = 0; i < 8; i++)
            {
                rst = SetAiRange(DevIndex, 1, i);
                if (rst < 0) { return rst; }
            }

            // Set the number of Ai OneShot points, collecting 1000 points per channel
            rst = SetAiOneShotCount(DevIndex, 1000);
            if (rst < 0) { return rst; }

            // Set the Ai trigger source, Ai software trigger
            rst = SetAiTrigSource(DevIndex, 0);
            if (rst < 0) { return rst; }

            // Set Ai ready, AiReady
            rst = AiReady(DevIndex, 1);
            if (rst < 0) { return rst; }

            // Issue the Ai software trigger command
            rst = SetAiSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            // Read the data obtained from Ai OneShot
            // Here, 1000 points are read from each channel. Since 8 channels were opened earlier, a total of 8000 points are stored in AiValue.
            // AiValue[0] to AiValue[999] are the data of channel ai 0.
            // AiValue[1000] to AiValue[1999] are the data of channel ai 1.
            // AiValue[2000] to AiValue[2999] are the data of channel ai 2.
            // AiValue[3000] to AiValue[3999] are the data of channel ai 3.
            // AiValue[4000] to AiValue[4999] are the data of channel ai 4.
            // AiValue[5000] to AiValue[5999] are the data of channel ai 5.
            // AiValue[6000] to AiValue[6999] are the data of channel ai 6.
            // AiValue[7000] to AiValue[7999] are the data of channel ai 7.
            rst = GetAiData(DevIndex, 1000, AiValue, ref AiFifoUsdw, 2000);
            if (rst < 0) { return rst; }

            Console.WriteLine("GetAiData Success.");

            // Clear the Ai software trigger flag
            rst = ClearAiSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            // Clear the Ai ready flag
            rst = AiReady(DevIndex, 0);
            if (rst < 0) { return rst; }

            // Close the device
            rst = CloseDevice(DevIndex);

            return rst;
        }
    }
}