﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;

using static Spcidevdll;

// This routine controls the data acquisition card to output an infinite non-cyclic analog arbitrary wave signal.
// This routine is applicable to the following models:
// PCI - 2253
// PCI - 31xx

namespace ao_waveform_infinite_non_circulation
{
    class Program
    {
        static int Main(string[] args)
        {
            int rst;
            int DevIndex = 0;
            int i, j;
            float WaveData;
            Random rd = new Random();

            // Open the device
            rst = OpenDevice(DevIndex);
            if (rst < 0) { return rst; }

            // Clear the waveform FIFO of Ao 0
            rst = ClearAoFifo(DevIndex, 0);
            if (rst < 0) { return rst; }

            // Set the output of Ao 0 to the infinite non-cyclic mode
            rst = SetAoMode(DevIndex, 0, 2);
            if (rst < 0) { return rst; }

            // Set the output sampling rate of Ao 0
            // Here it is set to 100000ns, that is, 10kS/s
            rst = SetAoSamplePeriod(DevIndex, 0, 100000);
            if (rst < 0) { return rst; }

            // Set the trigger source of Ao 0, software trigger for Ao 0
            rst = SetAoTrigSource(DevIndex, 0, 2);
            if (rst < 0) { return rst; }

            // First send 1000 points of waveform data to the hardware
            for (i = 0; i < 1000; i++)
            {
                WaveData = (float)rd.Next(0, 100) / (float)100;
                rst = SetAoFifo(DevIndex, 0, WaveData);
                if (rst < 0) { return rst; }
            }

            // Set Ao ready, AoReady
            rst = AoReady(DevIndex, 0, 1);
            if (rst < 0) { return rst; }

            // Issue the software trigger command for Ao 0
            rst = SetAoSoftTrig(DevIndex, 0);
            if (rst < 0) { return rst; }

            // Start sending non-cyclic waveform data to the hardware
            // Here, only 10 times of sending are used as an example
            for (i = 0; i < 10; i++)
            {
                // Send another 1000 points of waveform data to the hardware
                for (j = 0; j < 1000; j++)
                {
                    WaveData = (float)rd.Next(0, 100) / (float)100;
                    rst = SetAoFifo(DevIndex, 0, WaveData);
                    if (rst < 0) { return rst; }
                }

                // Send 1000 points of waveform data to the hardware every 100ms
                // Ensure that there is enough data in the hardware FIFO without overflowing
                Thread.Sleep(100);
            }

            Console.WriteLine("press any key to quit.");
            Console.ReadKey();

            // Clear the software trigger flag of Ao 0
            rst = ClearAoSoftTrig(DevIndex, 0);
            if (rst < 0) { return rst; }

            // Clear the ready flag of Ao 0
            rst = AoReady(DevIndex, 0, 0);
            if (rst < 0) { return rst; }

            // Close the device
            rst = CloseDevice(DevIndex);

            return rst;
        }
    }
}