﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using static Spcidevdll;

// This routine controls the analog output channels of the data acquisition card to output an arbitrary wave signal a specified number of times.
// This routine is applicable to the following models:
// PCI - 2253
// PCI - 31xx

namespace ao_waveform_n_cycle
{
    class Program
    {
        static int Main(string[] args)
        {
            int rst;
            int DevIndex = 0;
            int i;
            float[] WaveData = new float[100];

            // Open the device
            rst = OpenDevice(DevIndex);
            if (rst < 0) { return rst; }

            // Clear the waveform FIFO of Ao 0
            rst = ClearAoFifo(DevIndex, 0);
            if (rst < 0) { return rst; }

            // Set the output of Ao 0 to the n - cycle mode
            rst = SetAoMode(DevIndex, 0, 1);
            if (rst < 0) { return rst; }

            // Set the output sampling rate of Ao 0
            // Here it is set to 100000ns, that is, 10kS/s
            rst = SetAoSamplePeriod(DevIndex, 0, 100000);
            if (rst < 0) { return rst; }

            // Set the number of output waveform cycles of Ao 0
            // Here it is set to output 10 times. If set to 0, it means infinite loop output
            rst = SetAoNCycleCount(DevIndex, 0, 10);
            if (rst < 0) { return rst; }

            // Set the trigger source of Ao 0, software trigger for Ao 0
            rst = SetAoTrigSource(DevIndex, 0, 2);
            if (rst < 0) { return rst; }

            // Generate 100 - point waveform data
            for (i = 0; i < 100; i++)
            {
                WaveData[i] = (((float)i) / 100) * 5;
            }

            // Set the waveform data of Ao 0
            // Write the 100 - point waveform data to the hardware
            for (i = 0; i < 100; i++)
            {
                rst = SetAoFifo(DevIndex, 0, WaveData[i]);
                if (rst < 0) { return rst; }
            }

            // Set Ao ready, AoReady
            rst = AoReady(DevIndex, 0, 1);
            if (rst < 0) { return rst; }

            // Issue the software trigger command for Ao 0
            rst = SetAoSoftTrig(DevIndex, 0);
            if (rst < 0) { return rst; }

            Console.WriteLine("press any key to quit.");
            Console.ReadKey();

            // Clear the software trigger flag of Ao 0
            rst = ClearAoSoftTrig(DevIndex, 0);
            if (rst < 0) { return rst; }

            // Clear the ready flag of Ao 0
            rst = AoReady(DevIndex, 0, 0);
            if (rst < 0) { return rst; }

            // Close the device
            rst = CloseDevice(DevIndex);

            return rst;
        }
    }
}