﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using static Spcidevdll;

// This routine controls the continuous acquisition of the digital input channels of the data acquisition card.
// This routine is applicable to the following models:
// PCI - 1132
// PCI - 1316
// PCI - 225x
// PCI - 3xxx
// PCI - 5xxx

namespace di_continuous
{
    class Program
    {
        static int Main(string[] args)
        {
            int rst;
            uint i;
            int DevIndex = 0;
            uint[] DiValue = new uint[1000];
            uint DiFifoUsdw = 0;

            // Open the device
            rst = OpenDevice(DevIndex);
            if (rst < 0) { return rst; }

            // Set the digital I/O direction
            // Since the digital I/O of PCI - 225x/3000/5000 can be set as input or output,
            // here all are set as input.
            // For models whose digital I/O does not support setting, this step can be skipped.
            rst = SetDioDir(DevIndex, 0xffffffff);
            if (rst < 0) { return rst; }

            // Set the Di sensitivity
            rst = SetDiSensitivity(DevIndex, 20000);
            if (rst < 0) { return rst; }

            // Set the Di acquisition mode to continuous acquisition
            rst = SetDiSampleMode(DevIndex, 2);
            if (rst < 0) { return rst; }

            // Set the Di sampling period to 10000ns, that is, 100kS/s
            rst = SetDiSamplePeriod(DevIndex, 10000);
            if (rst < 0) { return rst; }

            // Set the Di trigger source, Di software trigger
            rst = SetDiTrigSource(DevIndex, 1);
            if (rst < 0) { return rst; }

            // Set Di ready, DiReady
            rst = DiReady(DevIndex, 1);
            if (rst < 0) { return rst; }

            // Issue the Di software trigger command
            rst = SetDiSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            // Read the data obtained from continuous Di acquisition
            // For continuous and uninterrupted data acquisition, just call the GetDiData function in a loop.
            // The obtained data is the result of continuous and uninterrupted acquisition. Here, it is only looped 10 times as an example.
            for (i = 0; i < 10; i++)
            {
                rst = GetDiData(DevIndex, 1000, DiValue, ref DiFifoUsdw, 2000);
                if (rst < 0) { return rst; }
                Console.WriteLine("Call GetDiData times: {0}", i);
            }

            // Clear the Di software trigger flag
            rst = ClearDiSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            // Clear the Di ready flag
            rst = DiReady(DevIndex, 0);
            if (rst < 0) { return rst; }

            // Close the device
            rst = CloseDevice(DevIndex);

            return rst;
        }
    }
}