﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;

using static Spcidevdll;

// This routine controls the edge counting of the digital input channels of the data acquisition card.
// This routine is applicable to the following models:
// PCI - 1132
// PCI - 1316
// PCI - 225x
// PCI - 3xxx
// PCI - 5xxx

namespace di_count
{
    class Program
    {
        static int Main(string[] args)
        {
            int rst;
            int i;
            int DevIndex = 0;
            uint DiCountValue = 0;

            // Open the device
            rst = OpenDevice(DevIndex);
            if (rst < 0) { return rst; }

            // Set the digital I/O direction
            // Since the digital I/O of PCI - 225x/3000/5000 can be set as input or output,
            // here all are set as input.
            // For models whose digital I/O does not support setting, this step can be skipped.
            rst = SetDioDir(DevIndex, 0xffffffff);
            if (rst < 0) { return rst; }

            // Set the Di sensitivity
            rst = SetDiSensitivity(DevIndex, 20000000);
            if (rst < 0) { return rst; }

            // Set the Di counting edge, set it to rising edge counting.
            // Each bit of the parameter corresponds to a Di channel.
            // Here, all 32 channels are set to rising edge counting.
            rst = SetDiCountEdge(DevIndex, 0xffffffff);
            if (rst < 0) { return rst; }

            // Enable the Di counting function
            rst = SetDiCountEn(DevIndex, 1);
            if (rst < 0) { return rst; }

            // Reset the count value of Di 0 to zero
            rst = ClearDiCountValue(DevIndex, 0);
            if (rst < 0) { return rst; }

            Thread.Sleep(10);

            // Read the Di counter value
            // Here, it is read 10 times.
            for (i = 0; i < 10; i++)
            {
                rst = GetDiCountValue(DevIndex, 0, ref DiCountValue);
                if (rst < 0) { return rst; }
                Console.WriteLine("Call GetDiCountValue {0} times. DiCountValue is: {1}", i + 1, DiCountValue);
                Thread.Sleep(1000);
            }

            // Disable the Di counting function
            rst = SetDiCountEn(DevIndex, 0);
            if (rst < 0) { return rst; }

            // Close the device
            rst = CloseDevice(DevIndex);

            return rst;
        }
    }
}