﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;

using static Spcidevdll;

// This routine controls the data acquisition card to output an infinite non-cyclic digital arbitrary wave signal.
// This routine is applicable to the following models:
// PCI - 1232
// PCI - 1316
// PCI - 225x
// PCI - 3xxx

namespace do_waveform_infinite_non_circulation
{
    class Program
    {
        static int Main(string[] args)
        {
            int rst;
            int DevIndex = 0;
            int i, j;
            uint WaveData;
            Random rd = new Random();

            // Open the device
            rst = OpenDevice(DevIndex);
            if (rst < 0) { return rst; }

            // Set the digital I/O direction
            // Here, all digital I/O channels are set as output.
            // Since the digital I/O of PCI - 225x/3000/5000 can be set as input or output,
            // here all are set as output.
            // For models whose digital I/O does not support setting, this step can be skipped.
            rst = SetDioDir(DevIndex, 0x00000000);
            if (rst < 0) { return rst; }

            // Clear the Do waveform FIFO
            rst = ClearDoFifo(DevIndex);
            if (rst < 0) { return rst; }

            // Set the Do output to the infinite non-cyclic mode
            rst = SetDoMode(DevIndex, 2);
            if (rst < 0) { return rst; }

            // Set the Do output sampling rate
            // Here it is set to 100000ns, that is, 10kS/s
            rst = SetDoSamplePeriod(DevIndex, 100000);
            if (rst < 0) { return rst; }

            // Set the Do trigger source, Do software trigger
            rst = SetDoTrigSource(DevIndex, 18);
            if (rst < 0) { return rst; }

            // First send 1000 points of waveform data to the hardware
            for (i = 0; i < 1000; i++)
            {
                WaveData = (uint)rd.Next();
                // Here should be SetDoFifo instead of SetAoFifo, the following is the corrected code
                rst = SetDoFifo(DevIndex, WaveData);
                if (rst < 0) { return rst; }
            }

            // Set Do ready, DoReady
            rst = DoReady(DevIndex, 1);
            if (rst < 0) { return rst; }

            // Issue the Do software trigger command
            rst = SetDoSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            // Start sending non-cyclic waveform data to the hardware
            // Here, only 10 times of sending are used as an example
            for (i = 0; i < 10; i++)
            {
                // Send another 1000 points of waveform data to the hardware
                for (j = 0; j < 1000; j++)
                {
                    WaveData = (uint)rd.Next();
                    rst = SetDoFifo(DevIndex, WaveData);
                    if (rst < 0) { return rst; }
                }

                // Send 1000 points of waveform data to the hardware every 100ms
                // Ensure that there is enough data in the hardware FIFO without overflowing
                Thread.Sleep(100);
            }

            Console.WriteLine("press any key to quit.");
            Console.ReadKey();

            // Clear the Do software trigger flag
            rst = ClearDoSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            // Clear the Do ready flag
            rst = DoReady(DevIndex, 0);
            if (rst < 0) { return rst; }

            // Close the device
            rst = CloseDevice(DevIndex);

            return rst;
        }
    }
}