﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using static Spcidevdll;

// This routine controls the digital output channels of the data acquisition card to output an arbitrary wave signal a specified number of times.
// This routine is applicable to the following models:
// PCI - 1232
// PCI - 1316
// PCI - 225x
// PCI - 3xxx

namespace do_waveform_n_cycle
{
    class Program
    {
        static int Main(string[] args)
        {
            int rst;
            int DevIndex = 0;
            int i;
            uint[] WaveData = new uint[100];
            Random rd = new Random();

            // Open the device
            rst = OpenDevice(DevIndex);
            if (rst < 0) { return rst; }

            // Set the digital I/O direction
            // Here, all digital I/O channels are set as output.
            // Since the digital I/O of PCI - 225x/3000/5000 can be set as input or output,
            // here all are set as output.
            // For models whose digital I/O does not support setting, this step can be skipped.
            rst = SetDioDir(DevIndex, 0x00000000);
            if (rst < 0) { return rst; }

            // Clear the Do waveform FIFO
            rst = ClearDoFifo(DevIndex);
            if (rst < 0) { return rst; }

            // Set the Do output to the n-cycle mode
            rst = SetDoMode(DevIndex, 1);
            if (rst < 0) { return rst; }

            // Set the Do output sampling rate
            // Here it is set to 100000ns, that is, 10kS/s
            rst = SetDoSamplePeriod(DevIndex, 100000);
            if (rst < 0) { return rst; }

            // Set the number of Do output waveform cycles
            // Here it is set to output 10 times. If set to 0, it means infinite loop output.
            rst = SetDoNCycleCount(DevIndex, 10);
            if (rst < 0) { return rst; }

            // Set the Do trigger source, Do software trigger
            rst = SetDoTrigSource(DevIndex, 18);
            if (rst < 0) { return rst; }

            // Generate 100-point waveform data
            for (i = 0; i < 100; i++)
            {
                WaveData[i] = (uint)rd.Next();
            }

            // Set the Do waveform data
            // Write the 100-point waveform data to the hardware
            for (i = 0; i < 100; i++)
            {
                rst = SetDoFifo(DevIndex, WaveData[i]);
                if (rst < 0) { return rst; }
            }

            // Set Do ready, DoReady
            rst = DoReady(DevIndex, 1);
            if (rst < 0) { return rst; }

            // Issue the Do software trigger command
            rst = SetDoSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            Console.WriteLine("press any key to quit.");
            Console.ReadKey();

            // Clear the Do software trigger flag
            rst = ClearDoSoftTrig(DevIndex);
            if (rst < 0) { return rst; }

            // Clear the Do ready flag
            rst = DoReady(DevIndex, 0);
            if (rst < 0) { return rst; }

            // Close the device
            rst = CloseDevice(DevIndex);

            return rst;
        }
    }
}